pub enum HarnessAuthenticationEnvironment {
LocalBrowser,
Headless,
}Expand description
Environment in which the native authentication interaction must work.
Variants
LocalBrowser
A local graphical browser may be opened by the native harness.
Headless
No browser can be opened on the machine running the harness.