pub fn harness_support_registry() -> SupportRegistryReportExpand description
Return the single compiled inventory used by product surfaces and audits.
pub fn harness_support_registry() -> SupportRegistryReportReturn the single compiled inventory used by product surfaces and audits.