pub fn resolve_live_runtime(
endpoint: &LiveRuntimeEndpoint,
expected: &LiveRuntimeSource,
) -> Result<ResolvedLiveRuntime, LiveRuntimeReceiptError>Expand description
Resolve an opaque endpoint and verify that it belongs to expected.
pub fn resolve_live_runtime(
endpoint: &LiveRuntimeEndpoint,
expected: &LiveRuntimeSource,
) -> Result<ResolvedLiveRuntime, LiveRuntimeReceiptError>Resolve an opaque endpoint and verify that it belongs to expected.