pub fn import_into_hermes(
session: &Session,
home: Option<&Path>,
) -> Result<HermesImported, Error>Expand description
Write session into the Hermes store at home (default: hermes_home)
through hermes sessions import.
pub fn import_into_hermes(
session: &Session,
home: Option<&Path>,
) -> Result<HermesImported, Error>Write session into the Hermes store at home (default: hermes_home)
through hermes sessions import.