pub enum LiveRuntimeReceiptError {
InvalidEndpoint,
NotLive,
IdentityMismatch,
Io(Error),
InvalidReceipt(String),
AmbiguousRuntime(String),
}Expand description
Receipt registration or resolution failure.
Variants
InvalidEndpoint
Opaque endpoint has an invalid scheme or identifier.
NotLive
Receipt no longer exists or its owning process is gone.
IdentityMismatch
Receipt exists but belongs to another source session or workspace.
Io(Error)
Receipt storage failed.
InvalidReceipt(String)
Receipt data was malformed or from another schema version.
AmbiguousRuntime(String)
More than one active receipt has the requested stable runtime id.