pub async fn refresh_token(
client: &Client,
ep: &OAuthEndpoints,
refresh_token: &str,
) -> Result<McpOAuthTokens, Error>Expand description
Exchange a refresh token for a new access token.
pub async fn refresh_token(
client: &Client,
ep: &OAuthEndpoints,
refresh_token: &str,
) -> Result<McpOAuthTokens, Error>Exchange a refresh token for a new access token.