OrchestrationCodec

Trait OrchestrationCodec 

pub trait OrchestrationCodec<W> {
    // Required methods
    fn compile(
        &self,
        home: &Path,
    ) -> Result<(W, Vec<ArtifactFidelity>), InterchangeError>;
    fn decompile(
        &self,
        orchestration: &W,
        dest: &Path,
    ) -> Result<Vec<ArtifactFidelity>, InterchangeError>;
}
A harness’s operational home compiled into an orchestration value and back.

Required Methods

fn compile( &self, home: &Path, ) -> Result<(W, Vec<ArtifactFidelity>), InterchangeError>

Read a home into the orchestration value, naming what each artifact reached.

fn decompile( &self, orchestration: &W, dest: &Path, ) -> Result<Vec<ArtifactFidelity>, InterchangeError>

Write the orchestration value as this harness’s home, naming what each artifact reached; a write that would have to guess is an error naming its gate.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors