pub type ReductionResult<T> = Result<T, ReductionError>;Expand description
Explicitly named alias for callers that also import another crate’s Result.
Aliased Type
pub enum ReductionResult<T> {
Ok(T),
Err(ReductionError),
}pub type ReductionResult<T> = Result<T, ReductionError>;Explicitly named alias for callers that also import another crate’s Result.
pub enum ReductionResult<T> {
Ok(T),
Err(ReductionError),
}