pub struct OpenCodeRuntimeBackend { /* private fields */ }Expand description
OpenCode live-runtime backend using its official HTTP API and SSE event
stream. OpenCodeRuntimeBackend::connect can join the server embedded in
an already-running TUI when that TUI was launched with a known host/port.
Implementations
Sourceimpl OpenCodeRuntimeBackend
impl OpenCodeRuntimeBackend
Sourcepub fn new() -> OpenCodeRuntimeBackend
pub fn new() -> OpenCodeRuntimeBackend
Launch a fresh opencode serve process for each connection.
Sourcepub fn connect(base_url: impl Into<String>) -> OpenCodeRuntimeBackend
pub fn connect(base_url: impl Into<String>) -> OpenCodeRuntimeBackend
Connect to an existing OpenCode server, including a TUI’s server when it was launched on a known address.
Sourcepub fn with_launch(self, launch: RuntimeLaunch) -> OpenCodeRuntimeBackend
pub fn with_launch(self, launch: RuntimeLaunch) -> OpenCodeRuntimeBackend
Override the command used when launching a new OpenCode server.