pub enum SessionFormat {
ClaudeCode,
Codex,
}Expand description
An on-disk session format supercode can both read and write.
Like an image editor that opens and exports several file formats, supercode
keeps one canonical in-memory model (Session) and converts to/from each
supported format on the edges.
Variants
Implementations
Sourceimpl SessionFormat
impl SessionFormat
Sourcepub fn source(self) -> SessionSource
pub fn source(self) -> SessionSource
The SessionSource a file of this format reports.