pub struct SupercodeHttpRuntimeBackend { /* private fields */ }Expand description
Adapter that joins one authenticated Supercode SDK runtime without taking ownership of the process or creating a second model loop.
Implementations
Sourceimpl SupercodeHttpRuntimeBackend
impl SupercodeHttpRuntimeBackend
Sourcepub fn new(receipt: ResolvedLiveRuntime) -> SupercodeHttpRuntimeBackend
pub fn new(receipt: ResolvedLiveRuntime) -> SupercodeHttpRuntimeBackend
Build an adapter from a trusted local receipt resolved by the host.